"use strict";

exports.__esModule = true;
exports.default = void 0;

require("core-js/modules/es6.object.assign");

require("core-js/modules/web.dom.iterable");

require("core-js/modules/es6.array.iterator");

require("core-js/modules/es6.object.keys");

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/**
 * @category communication
 * @component badge
 * @variations collab-ui-react
 */
var Badge = function Badge(props) {
  var className = props.className,
      rounded = props.rounded,
      color = props.color,
      otherHTMLProps = _objectWithoutPropertiesLoose(props, ["className", "rounded", "color"]);

  return _react.default.createElement("span", _extends({
    className: "cui-badge" + ("" + (rounded && ' cui-badge--round' || '')) + ("" + (color && " cui-badge--" + color || '')) + ("" + (className && " " + className || ''))
  }, otherHTMLProps), props.children);
};

Badge.displayName = 'Badge';
Badge.propTypes = {
  /** @prop Children nodes to render inside Accordion | null */
  children: _propTypes.default.element,

  /** @prop Optional css class string | '' */
  className: _propTypes.default.string,

  /** @prop Optional color prop type | null */
  color: _propTypes.default.string,

  /** @prop Optional rounded corners for the Badge | false */
  rounded: _propTypes.default.bool
};
Badge.defaultProps = {
  children: null,
  className: '',
  rounded: false
};
var _default = Badge;
/**
* @name Default Badges
* @description Default state of badge.
*
* @category communication
* @component badge
* @section default
*
* @js
import { Badge } from '@collab-ui/react';

export default function Types() {
    return (
      <div className='row'>
        <div className='example-spacing'>
          <p><span className='h3'>Default</span></p>
          <div>
            <Badge>
                <div>Default</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Blue</span><code>color='blue'</code></p>
          <div>
            <Badge color='blue'>
              <div>Blue</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Red</span><code>color='red'</code></p>
          <div>
            <Badge color='red'>
              <div>Red</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Yellow</span><code>color='yellow'</code></p>
          <div>
            <Badge color='yellow'>
              <div>Yellow</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Green</span><code>color='green'</code></p>
          <div>
            <Badge color='green'>
              <div>Green</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Mint</span><code>color='mint'</code></p>
          <div>
            <Badge color='mint'>
              <div>Mint</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Default</span><code>color='pastel'</code></p>
          <div>
            <Badge color='pastel'>
                <div>Default</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Blue</span><code>color='blue-pastel'</code></p>
          <div>
            <Badge color='blue-pastel'>
              <div>Blue</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Red</span><code>color='red-pastel'</code></p>
          <div>
            <Badge color='red-pastel'>
              <div>Red</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Yellow</span><code>color='yellow-pastel'</code></p>
          <div>
            <Badge color='yellow-pastel'>
              <div>Yellow</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Green</span><code>color='green-pastel'</code></p>
          <div>
            <Badge color='green-pastel'>
              <div>Green</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Mint</span><code>color='mint-pastel'</code></p>
          <div>
            <Badge color='mint-pastel'>
              <div>Mint</div>
            </Badge>
          </div>
        </div>
      </div>
    );
  }

**/

/**
* @name Rounded Badges
* @description Rounded state of badges
*
* @category communication
* @component badge
* @section round
*
*
* @js
import { Badge } from '@collab-ui/react';

export default function Rounded() {
    return (
      <div className='row'>
        <div className='example-spacing'>
          <p><span className='h3'>Default</span><code>rounded</code></p>
          <div>
            <Badge rounded>
                <div>Default</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Blue</span><code>rounded color='blue'</code></p>
          <div>
            <Badge color='blue' rounded>
              <div>Blue</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Red</span><code>rounded color='red'</code></p>
          <div>
            <Badge color='red' rounded>
              <div>Red</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Yellow</span><code>rounded color='yellow'</code></p>
          <div>
            <Badge color='yellow' rounded>
              <div>Yellow</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Green</span><code>rounded color='green'</code></p>
          <div>
            <Badge color='green' rounded>
              <div>Green</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Mint</span><code>rounded color='mint'</code></p>
          <div>
            <Badge color='mint' rounded>
              <div>Mint</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Default</span><code>rounded color='pastel'</code></p>
          <div>
            <Badge color='pastel' rounded>
                <div>Default</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Blue</span><code>rounded color='blue-pastel'</code></p>
          <div>
            <Badge color='blue-pastel' rounded>
              <div>Blue</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Red</span><code>rounded color='red-pastel'</code></p>
          <div>
            <Badge color='red-pastel' rounded>
              <div>Red</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Yellow</span><code>rounded color='yellow-pastel'</code></p>
          <div>
            <Badge color='yellow-pastel' rounded>
              <div>Yellow</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Green</span><code>rounded color='green-pastel'</code></p>
          <div>
            <Badge color='green-pastel' rounded>
              <div>Green</div>
            </Badge>
          </div>
          <br></br>
          <p><span className='h3'>Mint</span><code>rounded color='mint-pastel'</code></p>
          <div>
            <Badge color='mint-pastel' rounded>
              <div>Mint</div>
            </Badge>
          </div>
          <br></br>
        </div>
      </div>
    );
  }
**/

exports.default = _default;